==> netbeans_6.5.orig.tar.gz: netbeans-6.5/nbjunit/test/unit/src/org/netbeans/testjunit/AskForOrgOpenideUtilEnumClass.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.testjunit;

import org.netbeans.junit.*;
import junit.framework.TestCase;
import org.openide.util.Exceptions;

/** This class needs to be in other package than
 * org.netbeans.junit in order to not be loaded by the application
 * classloader but by the started NetBeans IDE
 * 
 * @author Jaroslav Tulach
 */
public class AskForOrgOpenideUtilEnumClass extends TestCase {

    public AskForOrgOpenideUtilEnumClass(String t) {
        super(t);
    }

    public void testOne() {
        try {
            ClassLoader l = AskForOrgOpenideUtilEnumClass.class.getClassLoader();
            if (l == NbTestCase.class.getClassLoader()) {
                fail("This test shall not be loaded by the same classloader!");
            }
            Class<?> access = Class.forName("org.openide.util.enum.ArrayEnumeration");
            System.setProperty("en.one", "OK");
        } catch (Exception ex) {
            Exceptions.printStackTrace(ex);
        }
    }
}

==> netbeans_6.8.orig.tar.gz: netbeans-6.8/nbjunit/test/unit/src/org/netbeans/testjunit/AskForOrgOpenideUtilEnumClass.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.testjunit;

import java.util.logging.Level;
import java.util.logging.Logger;
import org.netbeans.junit.*;
import junit.framework.TestCase;

/** This class needs to be in other package than
 * org.netbeans.junit in order to not be loaded by the application
 * classloader but by the started NetBeans IDE
 * 
 * @author Jaroslav Tulach
 */
public class AskForOrgOpenideUtilEnumClass extends TestCase {

    public AskForOrgOpenideUtilEnumClass(String t) {
        super(t);
    }

    public void testOne() {
        try {
            ClassLoader l = AskForOrgOpenideUtilEnumClass.class.getClassLoader();
            if (l == NbTestCase.class.getClassLoader()) {
                fail("This test shall not be loaded by the same classloader!");
            }
            Class<?> access = Class.forName("org.openide.util.enum.ArrayEnumeration");
            System.setProperty("en.one", "OK");
        } catch (Exception ex) {
            Logger.getLogger("testOne").log(Level.INFO, ex.getMessage(), ex);
        }
    }
}
